@@ -35,8 +35,11 @@ class Logger:
         os.environ['PATH'] = os.environ['PATH']+';'+';'.join(sys.path)
                 
         if 'SOURCE_FOLDER' in os.environ:
-            commompath = os.path.commonpath([source,os.environ['SOURCE_FOLDER']])
-            source = source.replace(commompath,'')
+            try:
+                commompath = os.path.commonpath([source,os.environ['SOURCE_FOLDER']])
+                source = source.replace(commompath,'')
+            except:
+                pass
 
         source = source.lstrip('\\').lstrip('/')
         source = source.replace('.py','')
