@@ -77,7 +77,7 @@ def S3SyncDownloadTimeSeries(path,shm_name):
 
 def S3SyncDownloadMetadata(pathpkl,name):
     
-    Logger.log.debug('AWS S3 Sync metadata %s...' % (name))
+    Logger.log.debug('AWS S3 Sync download metadata %s...' % (name))
     folder=str(pathpkl.parents[0]).replace(\
         os.environ['DATABASE_FOLDER'],'')
     
@@ -110,19 +110,20 @@ def S3SyncDownloadMetadata(pathpkl,name):
     rc = process.poll()
     success= rc==0
     if success:
-        Logger.log.debug('AWS S3 Sync metadata %s DONE!' % (name))
+        Logger.log.debug('AWS S3 Sync download metadata %s DONE!' % (name))
     else:
-        Logger.log.error('AWS S3 Sync metadata %s ERROR!' % (name))
-        Logger.log.error('AWS S3 Sync metadata \"%s\"' % (''.join(process.stderr.readlines())))
+        Logger.log.error('AWS S3 Sync download metadata %s ERROR!' % (name))
+        Logger.log.error('AWS S3 Sync download metadata \"%s\"' % (''.join(process.stderr.readlines())))
     return success
 
 def S3Upload(localfilepath):
-    localfilepath = str(localfilepath).replace('\\','/')                
-    Logger.log.debug('Uploading to S3 '+str(localfilepath)+' ...')
-    try:        
-        remotefilepath = str(localfilepath).replace(\
+    remotefilepath = str(localfilepath).replace(\
             os.environ['DATABASE_FOLDER'],os.environ['S3_BUCKET'])   
-        remotefilepath = remotefilepath.replace('\\','/')        
+    remotefilepath = remotefilepath.replace('\\','/')        
+    localfilepath = str(localfilepath).replace('\\','/')              
+      
+    Logger.log.debug('Uploading to S3 '+str(localfilepath)+' ...')
+    try:                
         session = boto3.Session(profile_name='s3readwrite')   
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
